searchNodes=[{"doc":"A implementation of RFC 6902 in pure Elixir. The patch can be a single change or a list of things that shall be changed. Therefore a list or a single JSON patch can be provided. Every patch belongs to a certain operation which influences the usage. According to RFC 6901 escaping of / and ~ is done by using ~1 for / and ~0 for ~ .","ref":"Jsonpatch.html","title":"Jsonpatch","type":"module"},{"doc":"Apply a Jsonpatch or a list of Jsonpatches to a map or struct. The whole patch will not be applied when any path is invalid or any other error occured. When a list is provided, the operations are applied in the order as they appear in the list. Atoms are never garbage collected. Therefore, Jsonpatch works by default only with maps which used binary strings as key. This behaviour can be controlled via the :keys option. Examples iex&gt; patch = [ ...&gt; % Jsonpatch.Operation.Add { path : &quot;/age&quot; , value : 33 } , ...&gt; % Jsonpatch.Operation.Replace { path : &quot;/hobbies/0&quot; , value : &quot;Elixir!&quot; } , ...&gt; % Jsonpatch.Operation.Replace { path : &quot;/married&quot; , value : true } , ...&gt; % Jsonpatch.Operation.Remove { path : &quot;/hobbies/2&quot; } , ...&gt; % Jsonpatch.Operation.Remove { path : &quot;/hobbies/1&quot; } , ...&gt; % Jsonpatch.Operation.Copy { from : &quot;/name&quot; , path : &quot;/surname&quot; } , ...&gt; % Jsonpatch.Operation.Move { from : &quot;/home&quot; , path : &quot;/work&quot; } , ...&gt; % Jsonpatch.Operation.Test { path : &quot;/name&quot; , value : &quot;Bob&quot; } ...&gt; ] iex&gt; target = %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; false , &quot;hobbies&quot; =&gt; [ &quot;Sport&quot; , &quot;Elixir&quot; , &quot;Football&quot; ] , &quot;home&quot; =&gt; &quot;Berlin&quot; } iex&gt; Jsonpatch . apply_patch ( patch , target ) { :ok , %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; true , &quot;hobbies&quot; =&gt; [ &quot;Elixir!&quot; ] , &quot;age&quot; =&gt; 33 , &quot;surname&quot; =&gt; &quot;Bob&quot; , &quot;work&quot; =&gt; &quot;Berlin&quot; } } iex&gt; # Patch will not be applied if test fails. The target will not be changed. iex&gt; patch = [ ...&gt; % Jsonpatch.Operation.Add { path : &quot;/age&quot; , value : 33 } , ...&gt; % Jsonpatch.Operation.Test { path : &quot;/name&quot; , value : &quot;Alice&quot; } ...&gt; ] iex&gt; target = %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; false , &quot;hobbies&quot; =&gt; [ &quot;Sport&quot; , &quot;Elixir&quot; , &quot;Football&quot; ] , &quot;home&quot; =&gt; &quot;Berlin&quot; } iex&gt; Jsonpatch . apply_patch ( patch , target ) { :error , % Jsonpatch.Error { patch : %{ &quot;op&quot; =&gt; &quot;test&quot; , &quot;path&quot; =&gt; &quot;/name&quot; , &quot;value&quot; =&gt; &quot;Alice&quot; } , patch_index : 1 , reason : { :test_failed , &quot;Expected value &#39; \\&quot; Alice \\&quot; &#39; at &#39;/name&#39;&quot; } } }","ref":"Jsonpatch.html#apply_patch/3","title":"Jsonpatch.apply_patch/3","type":"function"},{"doc":"Apply a Jsonpatch or a list of Jsonpatches to a map or struct. In case of an error it will raise an exception. When a list is provided, the operations are applied in the order as they appear in the list. (See Jsonpatch.apply_patch/2 for more details)","ref":"Jsonpatch.html#apply_patch!/3","title":"Jsonpatch.apply_patch!/3","type":"function"},{"doc":"Creates a patch from the difference of a source map to a destination map or list. Examples iex&gt; source = %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; false , &quot;hobbies&quot; =&gt; [ &quot;Elixir&quot; , &quot;Sport&quot; , &quot;Football&quot; ] } iex&gt; destination = %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; true , &quot;hobbies&quot; =&gt; [ &quot;Elixir!&quot; ] , &quot;age&quot; =&gt; 33 } iex&gt; Jsonpatch . diff ( source , destination ) [ % Jsonpatch.Operation.Replace { path : &quot;/married&quot; , value : true } , % Jsonpatch.Operation.Remove { path : &quot;/hobbies/2&quot; } , % Jsonpatch.Operation.Remove { path : &quot;/hobbies/1&quot; } , % Jsonpatch.Operation.Replace { path : &quot;/hobbies/0&quot; , value : &quot;Elixir!&quot; } , % Jsonpatch.Operation.Add { path : &quot;/age&quot; , value : 33 } ]","ref":"Jsonpatch.html#diff/2","title":"Jsonpatch.diff/2","type":"function"},{"doc":"A valid Jsonpatch operation by RFC 6902","ref":"Jsonpatch.html#t:t/0","title":"Jsonpatch.t/0","type":"type"},{"doc":"Describe an error that occured while patching.","ref":"Jsonpatch.Error.html","title":"Jsonpatch.Error","type":"module"},{"doc":"","ref":"Jsonpatch.Error.html#t:t/0","title":"Jsonpatch.Error.t/0","type":"type"},{"doc":"The add operation is the operation for creating/updating values. Values can be inserted in a list using an index or appended using a - . Examples iex&gt; add = % Add { path : &quot;/a/b&quot; , value : 1 } iex&gt; target = %{ &quot;a&quot; =&gt; %{ &quot;c&quot; =&gt; false } } iex&gt; Jsonpatch.Operation.Add . apply ( add , target , [ ] ) { :ok , %{ &quot;a&quot; =&gt; %{ &quot;b&quot; =&gt; 1 , &quot;c&quot; =&gt; false } } } iex&gt; add = % Add { path : &quot;/a/1&quot; , value : &quot;b&quot; } iex&gt; target = %{ &quot;a&quot; =&gt; [ &quot;a&quot; , &quot;c&quot; ] } iex&gt; Jsonpatch.Operation.Add . apply ( add , target , [ ] ) { :ok , %{ &quot;a&quot; =&gt; [ &quot;a&quot; , &quot;b&quot; , &quot;c&quot; ] } } iex&gt; add = % Add { path : &quot;/a/-&quot; , value : &quot;z&quot; } iex&gt; target = %{ &quot;a&quot; =&gt; [ &quot;x&quot; , &quot;y&quot; ] } iex&gt; Jsonpatch.Operation.Add . apply ( add , target , [ ] ) { :ok , %{ &quot;a&quot; =&gt; [ &quot;x&quot; , &quot;y&quot; , &quot;z&quot; ] } }","ref":"Jsonpatch.Operation.Add.html","title":"Jsonpatch.Operation.Add","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Add.html#apply/3","title":"Jsonpatch.Operation.Add.apply/3","type":"function"},{"doc":"","ref":"Jsonpatch.Operation.Add.html#t:t/0","title":"Jsonpatch.Operation.Add.t/0","type":"type"},{"doc":"Represents the handling of JSON patches with a copy operation. Examples iex&gt; copy = %Jsonpatch.Operation.Copy{from: &quot;/a/b&quot;, path: &quot;/a/e&quot;} iex&gt; target = %{&quot;a&quot; =&gt; %{&quot;b&quot; =&gt; %{&quot;c&quot; =&gt; &quot;Bob&quot;}}, &quot;d&quot; =&gt; false} iex&gt; Jsonpatch.Operation.Copy.apply(copy, target, []) {:ok, %{&quot;a&quot; =&gt; %{&quot;b&quot; =&gt; %{&quot;c&quot; =&gt; &quot;Bob&quot;}, &quot;e&quot; =&gt; %{&quot;c&quot; =&gt; &quot;Bob&quot;}}, &quot;d&quot; =&gt; false}}","ref":"Jsonpatch.Operation.Copy.html","title":"Jsonpatch.Operation.Copy","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Copy.html#apply/3","title":"Jsonpatch.Operation.Copy.apply/3","type":"function"},{"doc":"","ref":"Jsonpatch.Operation.Copy.html#t:t/0","title":"Jsonpatch.Operation.Copy.t/0","type":"type"},{"doc":"Move operations change the position of values in map or struct. Examples iex&gt; move = % Jsonpatch.Operation.Move { from : &quot;/a/b&quot; , path : &quot;/a/e&quot; } iex&gt; target = %{ &quot;a&quot; =&gt; %{ &quot;b&quot; =&gt; %{ &quot;c&quot; =&gt; &quot;Bob&quot; } } , &quot;d&quot; =&gt; false } iex&gt; Jsonpatch.Operation.Move . apply ( move , target , [ ] ) { :ok , %{ &quot;a&quot; =&gt; %{ &quot;e&quot; =&gt; %{ &quot;c&quot; =&gt; &quot;Bob&quot; } } , &quot;d&quot; =&gt; false } }","ref":"Jsonpatch.Operation.Move.html","title":"Jsonpatch.Operation.Move","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Move.html#apply/3","title":"Jsonpatch.Operation.Move.apply/3","type":"function"},{"doc":"","ref":"Jsonpatch.Operation.Move.html#t:t/0","title":"Jsonpatch.Operation.Move.t/0","type":"type"},{"doc":"A JSON patch remove operation is responsible for removing values. Examples iex&gt; remove = % Jsonpatch.Operation.Remove { path : &quot;/a/b&quot; } iex&gt; target = %{ &quot;a&quot; =&gt; %{ &quot;b&quot; =&gt; %{ &quot;c&quot; =&gt; &quot;Bob&quot; } } , &quot;d&quot; =&gt; false } iex&gt; Jsonpatch.Operation.Remove . apply ( remove , target , [ ] ) { :ok , %{ &quot;a&quot; =&gt; %{ } , &quot;d&quot; =&gt; false } } iex&gt; remove = % Jsonpatch.Operation.Remove { path : &quot;/a/b&quot; } iex&gt; target = %{ &quot;a&quot; =&gt; %{ &quot;b&quot; =&gt; nil } , &quot;d&quot; =&gt; false } iex&gt; Jsonpatch.Operation.Remove . apply ( remove , target , [ ] ) { :ok , %{ &quot;a&quot; =&gt; %{ } , &quot;d&quot; =&gt; false } }","ref":"Jsonpatch.Operation.Remove.html","title":"Jsonpatch.Operation.Remove","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Remove.html#apply/3","title":"Jsonpatch.Operation.Remove.apply/3","type":"function"},{"doc":"","ref":"Jsonpatch.Operation.Remove.html#t:t/0","title":"Jsonpatch.Operation.Remove.t/0","type":"type"},{"doc":"The replace module helps replacing values in maps and structs by paths. Examples iex&gt; add = % Jsonpatch.Operation.Replace { path : &quot;/a/b&quot; , value : 1 } iex&gt; target = %{ &quot;a&quot; =&gt; %{ &quot;b&quot; =&gt; 2 } } iex&gt; Jsonpatch.Operation.Replace . apply ( add , target , [ ] ) { :ok , %{ &quot;a&quot; =&gt; %{ &quot;b&quot; =&gt; 1 } } }","ref":"Jsonpatch.Operation.Replace.html","title":"Jsonpatch.Operation.Replace","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Replace.html#apply/3","title":"Jsonpatch.Operation.Replace.apply/3","type":"function"},{"doc":"","ref":"Jsonpatch.Operation.Replace.html#t:t/0","title":"Jsonpatch.Operation.Replace.t/0","type":"type"},{"doc":"A test operation in a JSON patch prevents the patch application or allows it. Examples iex&gt; test = %Jsonpatch.Operation.Test{path: &quot;/x/y&quot;, value: &quot;Bob&quot;} iex&gt; target = %{&quot;x&quot; =&gt; %{&quot;y&quot; =&gt; &quot;Bob&quot;}} iex&gt; Jsonpatch.Operation.Test.apply(test, target, []) {:ok, %{&quot;x&quot; =&gt; %{&quot;y&quot; =&gt; &quot;Bob&quot;}}}","ref":"Jsonpatch.Operation.Test.html","title":"Jsonpatch.Operation.Test","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Test.html#apply/3","title":"Jsonpatch.Operation.Test.apply/3","type":"function"},{"doc":"","ref":"Jsonpatch.Operation.Test.html#t:t/0","title":"Jsonpatch.Operation.Test.t/0","type":"type"},{"doc":"Types","ref":"Jsonpatch.Types.html","title":"Jsonpatch.Types","type":"module"},{"doc":"","ref":"Jsonpatch.Types.html#t:casted_array_index/0","title":"Jsonpatch.Types.casted_array_index/0","type":"type"},{"doc":"","ref":"Jsonpatch.Types.html#t:casted_fragment/0","title":"Jsonpatch.Types.casted_fragment/0","type":"type"},{"doc":"","ref":"Jsonpatch.Types.html#t:casted_object_key/0","title":"Jsonpatch.Types.casted_object_key/0","type":"type"},{"doc":"","ref":"Jsonpatch.Types.html#t:convert_fn/0","title":"Jsonpatch.Types.convert_fn/0","type":"type"},{"doc":"","ref":"Jsonpatch.Types.html#t:error/0","title":"Jsonpatch.Types.error/0","type":"type"},{"doc":"","ref":"Jsonpatch.Types.html#t:error_reason/0","title":"Jsonpatch.Types.error_reason/0","type":"type"},{"doc":"","ref":"Jsonpatch.Types.html#t:json_container/0","title":"Jsonpatch.Types.json_container/0","type":"type"},{"doc":"Keys options: :strings (default) - decodes path fragments as binary strings :atoms - path fragments are converted to atoms :atoms! - path fragments are converted to existing atoms {:custom, convert_fn} - path fragments are converted with convert_fn","ref":"Jsonpatch.Types.html#t:opt_keys/0","title":"Jsonpatch.Types.opt_keys/0","type":"type"},{"doc":"Types options: :keys - controls how path fragments are decoded.","ref":"Jsonpatch.Types.html#t:opts/0","title":"Jsonpatch.Types.opts/0","type":"type"},{"doc":"JsonpatchException will be raised if a patch is applied with &quot;!&quot; and the patching fails.","ref":"JsonpatchException.html","title":"JsonpatchException","type":"exception"},{"doc":"An implementation of RFC 6902 in pure Elixir. Features: Creating a patch by comparing to maps and lists Apply patches to maps and lists - supports operations: add replace remove copy move test Escaping of &quot; / &quot; (by &quot; ~1 &quot;) and &quot; ~ &quot; (by &quot; ~0 &quot;) Allow usage of - for appending things to list (Add and Copy operation)","ref":"readme.html","title":"Jsonpatch","type":"extras"},{"doc":"Installation The package can be installed by adding jsonpatch to your list of dependencies in mix.exs : def deps do [ { :jsonpatch , &quot;~&gt; 1.0.1&quot; } ] end The docs can be found at https://hexdocs.pm/jsonpatch . Create a diff iex&gt; source = %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; false , &quot;hobbies&quot; =&gt; [ &quot;Sport&quot; , &quot;Elixir&quot; , &quot;Football&quot; ] } iex&gt; destination = %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; true , &quot;hobbies&quot; =&gt; [ &quot;Elixir!&quot; ] , &quot;age&quot; =&gt; 33 } iex&gt; Jsonpatch . diff ( source , destination ) { :ok , [ % Jsonpatch.Operation.Add { path : &quot;/age&quot; , value : 33 } , % Jsonpatch.Operation.Replace { path : &quot;/hobbies/0&quot; , value : &quot;Elixir!&quot; } , % Jsonpatch.Operation.Replace { path : &quot;/married&quot; , value : true } , % Jsonpatch.Operation.Remove { path : &quot;/hobbies/1&quot; } , % Jsonpatch.Operation.Remove { path : &quot;/hobbies/2&quot; } ] } Apply patches iex&gt; patch = [ % Jsonpatch.Operation.Add { path : &quot;/age&quot; , value : 33 } , % Jsonpatch.Operation.Replace { path : &quot;/hobbies/0&quot; , value : &quot;Elixir!&quot; } , % Jsonpatch.Operation.Replace { path : &quot;/married&quot; , value : true } , % Jsonpatch.Operation.Remove { path : &quot;/hobbies/1&quot; } , % Jsonpatch.Operation.Remove { path : &quot;/hobbies/2&quot; } ] iex&gt; target = %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; false , &quot;hobbies&quot; =&gt; [ &quot;Sport&quot; , &quot;Elixir&quot; , &quot;Football&quot; ] } iex&gt; Jsonpatch . apply_patch ( patch , target ) { :ok , %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; true , &quot;hobbies&quot; =&gt; [ &quot;Elixir!&quot; ] , &quot;age&quot; =&gt; 33 } }","ref":"readme.html#getting-started","title":"Jsonpatch - Getting started","type":"extras"},{"doc":"Official RFC 6902 Inspiration: python-json-patch","ref":"readme.html#important-sources","title":"Jsonpatch - Important sources","type":"extras"}]